Plot Age Fit
PlotAgeFit.RdThis function creates a plot comparing observed and predicted age compositions for a specified type.
Arguments
- x
A list containing the observed and predicted age compositions. Default is
bc.- title
A character string for the plot title. Default is NULL.
- type
A character string specifying the type of composition to plot. Default is "fishery".
- fage
An integer specifying the first age to include in the plot. Default is 2.
- lage
An integer specifying the last age to include in the plot. Default is 7.