Read output file from the random effects (RE) model into a data.frame
read_re_output.RdRead output file from the random effects (RE) model into a data.frame
Arguments
- file
A character string of the file to be read in, defaulting to 'rwout.rep' in the current working directory.
- skip_data
Whether to skip returning columns representing the data inputs. If TRUE these are included and will have NA values for any missing years
- use_names
Whether to use the names written by the RE model or to use more meaningful ones (default)